import React, { PureComponent } from 'react';
import PropTypes from 'prop-types';
import SidebarWrapper from './SidebarWrapper';


class Sidebar extends PureComponent {
  static propTypes = {
    children: PropTypes.node.isRequired,
    isActive: PropTypes.bool.isRequired,
    hideSidebar: PropTypes.func.isRequired,
    side: PropTypes.oneOf(['left', 'right']).isRequired,
    isOpen: PropTypes.bool.isRequired,
    zIndex: PropTypes.number.isRequired,
  }

  componentWillMount() {
    this.focusedElBeforeOpen = document.activeElement;
  }

  componentDidMount() {
    this.sidebar.focus();
    document.addEventListener('focus', this.handleFocus, true);
    document.addEventListener('keydown', this.handleEscape);
  }

  handleFocus = (event) => {
    if (this.props.isActive && !this.sidebar.contains(event.target)) {
      event.stopPropagation();
      this.sidebar.focus();
    }
  }

  handleEscape = (event) => {
    if (this.props.isActive && (!event.keyCode || event.keyCode === 27)) {
      this.props.hideSidebar();
    }
  }

  componentWillUnmount() {
    document.removeEventListener('focus', this.handleFocus, true);
    document.removeEventListener('keydown', this.handleEscape);
    this.focusedElBeforeOpen.focus();
  }

  render() {
    const {
      ariaLabelledBy,
      isOpen,
      side,
      zIndex,
      children,
    } = this.props;
    return (
      <SidebarWrapper
        tabIndex={0}
        role="dialog"
        innerRef={(sidebar) => { this.sidebar = sidebar; }}
        aria-labelledby={ariaLabelledBy}
        isOpen={isOpen}
        side={side}
        zIndex={zIndex}
      >
        {children}
      </SidebarWrapper>
    );
  }
}

export default Sidebar;
