import React, { PureComponent, Fragment } from 'react';
import PropTypes from 'prop-types';

import withSidebarsProps from '../redux/withSidebarsProps';
import Overlay from './Overlay';
import Sidebar from './Sidebar';

class Sidebars extends PureComponent {
  static propTypes = {
    startingZIndex: PropTypes.number,
    sidebars: PropTypes.array.isRequired,
    handleHidingSidebar: PropTypes.func.isRequired,
    components: PropTypes.object.isRequired,
  };

  static defaultProps = {
    startingZIndex: 3,
  }

  hideSidebar = component => () => {
    this.props.handleHidingSidebar(component);
  }

  render() {
    const { components, sidebars, startingZIndex } = this.props;
    return (
      <Fragment>
        {sidebars.map((sidebar, index) => {
          const {
            isVisible,
            side,
            component,
            sidebarProps,
          } = sidebar;
          const SpecificComponent = components[component];
          const id = `sidebar-${component}`;
          return (
            <Fragment key={`${component}-${side}`}>
              <Overlay
                isOpen={isVisible}
                zIndex={startingZIndex + index}
              />
              <Sidebar
                role="dialog"
                ariaLabelledBy={id}
                isOpen={isVisible}
                side={side}
                zIndex={startingZIndex + index}
                isActive={index === sidebars.length - 1}
                hideSidebar={this.hideSidebar(component)}
              >
                <SpecificComponent
                  titleId={id}
                  sidebarProps={sidebarProps}
                  hideSidebar={this.hideSidebar(component)}
                />
              </Sidebar>
            </Fragment>
          );
        })}
      </Fragment>
    );
  }
}

export default withSidebarsProps(Sidebars);
