import React, { PureComponent } from 'react';
import PropTypes from 'prop-types';
import { connect } from 'react-redux';
import { bindActionCreators } from 'redux';
import * as sidebarsActionCreators from './actions';

function withSidebarsProps(Component) {
  class ComponentWrapper extends PureComponent {
    static propTypes = {
      sidebars: PropTypes.array.isRequired,
      handleHidingSidebar: PropTypes.func.isRequired,
      handleOpeningSidebar: PropTypes.func.isRequired,
    }

    render() {
      return (
        <Component {...this.props} />
      );
    }
  }

  return connect(
    ({ sidebars }) => ({ sidebars: sidebars.sidebars }),
    dispatch => bindActionCreators(sidebarsActionCreators, dispatch),
  )(ComponentWrapper);
}

export default withSidebarsProps;
